#
# spec file for package python-tweepy
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-tweepy
Version:        3.5.0
Release:        2.4
Url:            http://github.com/joshthecoder/tweepy
Summary:        Twitter library for python
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/t/tweepy/tweepy-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-pip
BuildRequires:  python-requests >= 2.4.3
BuildRequires:  python-requests-oauthlib >= 0.4.1
BuildRequires:  python-setuptools
BuildRequires:  python-six >= 1.7.3
Requires:       python-requests >= 2.4.3
Requires:       python-requests-oauthlib >= 0.4.1
Requires:       python-six >= 1.7.3
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
A library for accessing the Twitter.com API. Supports OAuth, covers the entire
API, and streaming API.

%prep
%setup -q -n tweepy-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
# remove the examples from site package root
rm -r %{buildroot}%{python_sitelib}/examples

%files
%defattr(-,root,root,-)
%{python_sitelib}/*

%changelog
* Thu Feb 18 2016 eshmarnev@suse.com
- update to version 3.5.0:
  New features:
  * Allow 'full_text' param when getting direct messages.
  * Explicitly return api code when parsing error.
  * Remove deprecated function and clean up codes.
  Bug Fixes
  * update_status: first positional argument should be 'status'.
  * Fix "TypeError: Can't convert 'bytes' object to str implicitly".
  * Fix duplicate raise in auth.py.
  Additional changes from version 3.4.0:
  New features:
  * Add API for account/settings.
  * Added RateLimitError for easily working with the rate limit.
  * Allow include_email param for verify_credentials API.
  * Added support for the "filter_level" parameter for the streaming API.
  Bug Fixes:
  * Streaming: don't decode stream bytes until json.decode.
  * Typo fix on _add_list_members, _remove_list_members properties.
  * Change raise in streaming.py to raise exception.
* Thu May 14 2015 benoit.monin@gmx.fr
- update to version 3.3.0:
  * Loosen our dependency requirements for Requests (>= 2.4.3)
  * Fix issue with streams freezing up on Python 3 (Issue #556)
  * Add keep_alive() callback to StreamListener when keep alive
    messages arrive
  * Fix issue with stream session headers not being used when
    restarting connection
  * Fix issue with streams getting stuck in a loop when connection
    dies. (PR #561)
- additional changes from version 3.2.0
  * Remove deprecated trends methods.
  * Fix tweepy.debug() to work in Python 3.
  * Fixed issue #529 - StreamListener language filter stopped
    working.
  * Add Documentation Page for streaming.
  * Add media/upload endpoint.
  * Add media_ids parameter to update_status().
- additional changes from version 3.1.0
  * Allow specifying your own ssl certificates for streaming client.
  * Distribute Python Wheels instead of dumb binaries.
  * Fix cursor invocation, passing args to underlying method.
    (https://github.com/tweepy/tweepy/issues/515)
  * Upgrade to Request 2.4.3
- additional changes from version 3.0
  * Added multiple list members operation api methods
    (add_list_members, remove_list_members).
  * Added sitestream endpoint.
  * Switch to using Requests instead of httplib.
  * Fully removed support for non-secure HTTP.
  * Proxy support.
  * Add API method for /statuses/lookup.json
  * Add missing 'count' parameter to followers_ids
  * Added allowed_param to update_profile_image
  * Comparison between Status objects
  * Extend on_data method by including a conditional to process
    warning messages and add the definition of the method to manage
    those warning messages
  * Better Python 3 support.
- additional changes from version 2.2
  * Added update_profile_banner endpoint.
  * Don't treat HTTP status codes in 200 range as errors.
  * Tests no longer packaged into egg releases.
  * Improve test stability and enable CI testing on pull requests.
  * Removed Basic Auth.
  * Use built-in timeout feature of httplib to fix appengine.
  * Added retweeters() endpoint.
  * Removed deprecated retweeted_by and retweeted_by_ids.
  * Improved datetime parsing. Should be more thread safe.
  * Enable coverage reporting. Upload reports to Coveralls.
    https://coveralls.io/r/tweepy/tweepy
  * Removed deprecated test() endpoint.
  * New stream listeners callback on_disconnect(). Called whenever
    "disconnect" messages arrive from Twitter before connection is
    killed.
  * Compare View
  * Use HTTPS by default.
  * Support setting the starting cursor postion (ex: Ex:
    Cursor(api.friends_ids, cursor=123456))
  * Added API.cached_result instance flag that is "True" when
    cached result is returned.
  * New Streaming client callbacks
  * Improvements to streaming client re-connection behavior /
    configuration.
    (https://github.com/tweepy/tweepy/commit/447f69cd3de67b0d241b9d4
    f669ecc9b9c0cdb54)
- add new build dependency python-pip
- remove python-simplejson from dependencies
- add new dependencies python-requests, python-requests-oauthlib
  and python-six to match requirements.txt
- remove the examples directory from site package root
* Fri Nov 15 2013 p.drouand@gmail.com
- Update to version 2.1
  + No changelog available
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Feb 11 2013 p.drouand@gmail.com
- Update to version 2.0:
  * No changelog available
* Mon Jan 14 2013 p.drouand@gmail.com
- Update to 1.12 version:
  * No changelog available
* Mon Jun 25 2012 saschpe@suse.de
- Update to version 1.9:
  + Upstream provides no changelog
* Tue May 31 2011 saschpe@suse.de
- Re-generated with py2pack
* Wed Sep 15 2010 pascal.bleser@opensuse.org
- initial version 1.7.1
